attribute vec3 position;
attribute float size;

uniform vec3 LightDirection;
uniform mat4 VMatrix;
uniform vec3 MaterialAmbient;
uniform vec3 MaterialDiffuse;
uniform vec3 MaterialSpecular;
uniform float MaterialAlpha;

varying vec2 texCoord;
varying vec3 eNormal;
varying vec3 eEyeVector;
varying vec3 eLightVector;
varying vec3 composedAmbientColor;
varying vec3 composedDiffuseColor;
varying vec3 composedSpecularColor;


void main()
{	
	// calculate the model-space vertex after applying the particle transformations (particle-position and -size)
	vec4 lVertex = gl_Vertex * size + vec4(position, 1);

	// transform the normal into eye space and normalize it
	// Using gl_NormalMatrix to keep correct normals even if the model is non-uniformly scaled
	eNormal = normalize(gl_NormalMatrix * gl_Normal);
	
	// calculate the Vector pointing from the vertex to the eye position, in eye space
	eEyeVector = -normalize( gl_ModelViewMatrix * lVertex ).xyz;
	
	// calculate the Vector pointing from the vertex to the light position (inverse lightVec), in eye space
	eLightVector = -normalize( VMatrix * vec4(LightDirection, 0) ).xyz;
		
	// precalculate composed Colors that do not change along the Pixelshader
	composedAmbientColor = MaterialAmbient;		// MaterialAmbient * dirLight.ambient;
	composedDiffuseColor = MaterialDiffuse;		// MaterialDiffuse * dirLight.diffuse;
	composedSpecularColor = MaterialSpecular;	// MaterialSpecular * dirLight.specular;

	texCoord = gl_MultiTexCoord0.st;	
	gl_Position = gl_ModelViewProjectionMatrix * lVertex;
} 

